package VMOMI::HostNetStackInstanceSystemStackKey;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
